
#define cs   6  // CS & DC can use pins 2, 6, 9, 10, 15, 20, 21, 22, 23
#define dc   17   //  but certain pairs must NOT be used: 2+10, 6+9, 20+23, 21+22
#define rst  16 // RST can use any pin

#include <Adafruit_GFX.h>
#include <Adafruit_ST7735.h>
#include <SPI.h>
#include <stdio.h>
#include<Wire.h>
#include <dht.h> //DHT library


#if defined(__SAM3X8E__)
#undef __FlashStringHelper::F(string_literal)
#define F(string_literal) string_literal
#endif


Adafruit_ST7735 tft = Adafruit_ST7735(cs, dc, rst);

//Sensor Connections
// PID sensor on pin 2 or D2
// DHT sensor on pin 3
// Soil moisture sensor on A0

#define DHT11_PIN 3

int sensor_value;
int sensor_pin = A0;
int output;
byte t;
byte h;
dht DHT;


//Black theme
//#define COLOR1 ST7735_WHITE
//#define COLOR2 ST7735_BLACK

//White theme
#define COLOR1 ST7735_BLACK
#define COLOR2 ST7735_WHITE

int text_color_humidex;
float humidity, temperature;
String message;
String stemp, shumid, city;
void setup(void) {

  Wire.begin(8); //address pin 8
  Wire.onReceive(receiveEvent);
  Wire.onRequest(requestEvent);
  Serial.begin(115200);
  tft.initR(INITR_GREENTAB);   // initialize a ST7735S chip, black tab
  tft.fillScreen(COLOR2);

  pinMode(2, INPUT); //PID sensor

}

void loop() {

  int chk = DHT.read11(DHT11_PIN);
  t = DHT.temperature;
  sensor_value = digitalRead(2); //PIR sensor conntected at D2
  output = analogRead(sensor_pin); //Soil moisture sensor
  output = 1020 - output;

Serial.println(t);
Serial.println(sensor_value);
Serial.println(output);

  // Table
  tft.drawRect(0, 0, 128, 160, COLOR1);
  tft.drawLine(0, 50, 128, 50, COLOR1);
  tft.drawLine(0, 100, 128, 100, COLOR1);

  // data is outputed

  temperature_to_lcd (temperature, 4);
  humidity_to_lcd (humidity, 55);
  location_to_lcd ();

}

// outputs temperature to LCD
void temperature_to_lcd (float temperature, unsigned char text_position )
{
  int text_color;

  tft.setCursor(4, text_position);
  tft.setTextColor(COLOR1, COLOR2);
  tft.setTextSize(1);
  tft.print("Temperature:");

  tft.setTextSize(3);
  tft.setCursor(1, text_position + 20);
  fix_number_position(temperature);
  tft.print(temperature, 1);

  tft.setCursor(108, text_position + 20);
  tft.print("C");
  tft.drawChar(90, text_position + 20, 247, text_color, COLOR2, 2); //degree symbol

}

//outputs humidity to LCD

void humidity_to_lcd (float humidity, unsigned char text_position )
{


  tft.setTextColor(COLOR1, COLOR2);
  tft.setCursor(4, text_position);
  tft.setTextSize(1);
  tft.println("Humidity:");
  tft.setTextSize(3);
  tft.setCursor(1, text_position + 20);

  fix_number_position(humidity);

  tft.print(humidity, 1);
  tft.print(" %");

}


void location_to_lcd ()

{
  int  text_position = 105;
  tft.setCursor(4, text_position);

  tft.setTextSize(1);
  tft.println("Location:");
  tft.setTextSize(2);

  tft.setCursor(1, text_position + 17);


  tft.print(city);
  tft.setCursor(108, text_position + 17);
  //  tft.print("A");
  //  tft.drawChar(90,text_position+17, 247, COLOR1, COLOR2, 2); //degree symbol
  tft.setCursor(1, text_position + 43);
  tft.setTextSize(1);
  // tft.println("Hyd/India");


}

// aligs number to constant position

void fix_number_position(float number)

{


  if ((number >= -40) && (number < -9.9))
  {
    ;
  }

  if ((number >= -9.9) && (number < 0.0))
  {
    tft.print(" ");
  }

  if ((number >= 0.0 ) && (number < 9.9))
  {
    tft.print("  ");
  }

  if ((number >= 9.9 ) && (number < 99.9))
  {
    tft.print(" ");
  }

  if ((number >= 99.9 ) && (number < 151))
  {
    tft.print("");
  }
}


void receiveEvent(int howMany) {

  int h;
  int len_h = 0;
  char wt[15] = {'\0'};
  char str[15] = {'\0'};
  int i;
  String temp;

  float t = Wire.read();
  Serial.println(t);

  while (Wire.available()) {

    str[i] = Wire.read();
    Serial.println(str[i]);
    i++;

  }

  temperature = t;
  Serial.println("TEMPERATURE");
  Serial.println(t);

  for (h = 0; h < 2; h++) {
    wt[len_h] = str[h];
    len_h++;
  }

  for (int c = 3; c < i ; c++) {
    temp += String(str[c]);
  }

  city = temp;
  shumid = wt;
  Serial.println("HUMIDITY");
  Serial.println(wt);
  humidity = shumid.toInt();
}

void requestEvent() {

  Wire.write(t);//write temperature value
  Wire.write(h); //write humidity value
  Wire.write(sensor_value); //Write PIR sensor value
  Wire.write(output); //write soil moisture sensorr value
}




